# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid *.list files interfering with signature test
%global debug_package %{nil}

# Store keys in a temp directory
%global gnupghome %(mktemp --directory)

Name:		perl-MooseX-GlobRef
Version:	0.0701
Release:	35.%{__distinit}%{__distvers}
Summary:	Store a Moose object in glob reference
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		http://search.cpan.org/dist/MooseX-GlobRef/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DE/DEXTER/MooseX-GlobRef-%{version}.tar.gz
Source1:	C0B10A5B.pub
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gnupg2
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Moose) >= 0.94
BuildRequires:	perl(Moose::Exporter)
BuildRequires:	perl(Moose::Object)
BuildRequires:	perl(Moose::Role)
BuildRequires:	perl(Moose::Util::MetaRole)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Exception::Assertion)
BuildRequires:	perl(Exception::Base)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(parent)
BuildRequires:	perl(Test::Assert)
BuildRequires:	perl(Test::Unit::Lite) >= 0.12
# Release Tests (Readonly needed only for xt/copyright.t, which we don't run)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling), hunspell-en
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Data::Dumper)
Requires:	perl(Moose::Object)

Obsoletes:	perl-MooseX-GlobRef-Object < %{version}-%{release}
Provides:	perl-MooseX-GlobRef-Object = %{version}-%{release}

%description
This meta-policy allows to store Moose object in glob reference or file
handle. The class attributes will be stored in anonymous hash associated
with glob reference. It allows to create a Moose version of IO::Handle.

%prep
%setup -q -n MooseX-GlobRef-%{version}

# Drop exec bits and avoid doc-file dependencies
chmod -c -x eg/*

# Import upstream's GPG key so we don't need to fetch it from a keyserver
# when running the signature test
export GNUPGHOME=%{gnupghome}
gpg2 --import %{SOURCE1}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
# === MAIN TEST SUITE === #
make test

# ===  RELEASE TESTS  === #
export GNUPGHOME=%{gnupghome}

RELEASE_TESTS="$(echo xt/*.t)"

# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"

# Signature test would fail on recent distros due to presence of MYMETA.*
[ -f MYMETA.yml ] && mv MYMETA.yml ..
[ -f MYMETA.json ] && mv MYMETA.json ..

make test TEST_FILES="$RELEASE_TESTS"

# Put any MYMETA.* files back where they were
[ -f ../MYMETA.yml ] && mv ../MYMETA.yml .
[ -f ../MYMETA.json ] && mv ../MYMETA.json .

%clean
rm -rf %{buildroot} %{gnupghome}

%files
%license LICENSE
%doc Changes Incompatibilities README eg/
%{perl_vendorlib}/MooseX/
%{_mandir}/man3/MooseX::GlobRef.3*
%{_mandir}/man3/MooseX::GlobRef::Object.3*
%{_mandir}/man3/MooseX::GlobRef::Role::Meta::Instance.3*
%{_mandir}/man3/MooseX::GlobRef::Role::Object.3*

%changelog
* Wed Mar 29 2023 Paul Howarth <paul@city-fan.org> - 0.0701-35
- Use SPDX-format license tag
- Use %%license unconditionally

* Thu Apr 26 2018 Paul Howarth <paul@city-fan.org> - 0.0701-20
- Use mktemp to create GNUPGHOME, simplifying build process
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop workaround for building with Test::More < 0.88
  - Spell check back-end is always hunspell

* Wed Sep  7 2016 Paul Howarth <paul@city-fan.org> - 0.0701-16
- Fix FTBFS when perl is not in the minimal buildroot
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 0.0701-11
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.0701-5
- BR:/R: perl(Data::Dumper)
- BR: perl(Carp), perl(constant), perl(Cwd), perl(Exception::Assertion),
  perl(Exception::Base), perl(File::Spec), perl(Moose::Exporter),
  perl(Moose::Role), perl(Moose::Util::MetaRole) and perl(Scalar::Util)
- Specify version requirements for Test::Pod and Test::Pod::Coverage
- Add workaround for failing manifest test due to MYMETA.*
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Perl::Critic always available
  - Never need aspell-en-gb dictionary
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Jul  4 2011 Paul Howarth <paul@city-fan.org> - 0.0701-4
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon May  9 2011 Paul Howarth <paul@city-fan.org> - 0.0701-3
- Import from Fedora

* Mon Mar 14 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.0701-2
- Remove obsoletes -> causing conflicts

* Mon Mar  7 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.0701-1
- Rename package to correct name

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0701-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec 09 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.0701-1
- Upstream update (Fix FTBFS: BZ 660747)
- Remove requires-filter, adjust BRs

* Thu May 13 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.07-5
- Fix build directory
- Reflect build directory having changed

* Mon May 03 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.07-4
- Mass rebuild with perl-5.12.0

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 0.07-3
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.07-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jun 08 2009 Chris Weyl <cweyl@alumni.drew.edu> 0.07-1
- Auto-update to 0.07 (by cpan-spec-update 0.01)
- Altered br on perl(Test::Unit::Lite) (0.11 => 0.12)

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.06-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 18 2009 Allisson Azevedo <allisson@gmail.com> 0.06-1
- Update to 0.06
- Added filter requires

* Thu Jan 29 2009 Allisson Azevedo <allisson@gmail.com> 0.04-1
- Initial rpm release
